pub struct CommandArgSpec {
pub name: String,
pub description: String,
pub required: bool,
pub variants: Vec<String>,
}Fields
name: Stringdescription: Stringrequired: boolvariants: Vec<String>Trait Implementations
Sourceimpl Clone for CommandArgSpec
impl Clone for CommandArgSpec
Sourcefn clone(&self) -> CommandArgSpec
fn clone(&self) -> CommandArgSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandArgSpec
impl Debug for CommandArgSpec
Sourceimpl<'de> Deserialize<'de> for CommandArgSpec
impl<'de> Deserialize<'de> for CommandArgSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommandArgSpec
impl JsonSchema for CommandArgSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandArgSpec
impl RefUnwindSafe for CommandArgSpec
impl Send for CommandArgSpec
impl Sync for CommandArgSpec
impl Unpin for CommandArgSpec
impl UnsafeUnpin for CommandArgSpec
impl UnwindSafe for CommandArgSpec